summaryrefslogtreecommitdiffstats
path: root/libkdchart
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:37:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:37:08 -0600
commitc70e40bd3f54a2c4d9ef57a36f19c996f4e00ed6 (patch)
tree9a07481bb1245dac332e7db600c556e1db79ecf3 /libkdchart
parent28723595822268551d3e050c3a83bf6ca5e17dd5 (diff)
downloadkmymoney-c70e40bd3f54a2c4d9ef57a36f19c996f4e00ed6.tar.gz
kmymoney-c70e40bd3f54a2c4d9ef57a36f19c996f4e00ed6.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'libkdchart')
-rw-r--r--libkdchart/KDChart.cpp8
-rw-r--r--libkdchart/KDChartAreaPainter.cpp2
-rw-r--r--libkdchart/KDChartAxesPainter.cpp8
-rw-r--r--libkdchart/KDChartBWPainter.cpp4
-rw-r--r--libkdchart/KDChartBarPainter.cpp4
-rw-r--r--libkdchart/KDChartCustomBox.h12
-rw-r--r--libkdchart/KDChartEnums.h8
-rw-r--r--libkdchart/KDChartHiLoPainter.cpp2
-rw-r--r--libkdchart/KDChartLinesPainter.cpp2
-rw-r--r--libkdchart/KDChartObjectFactory.cpp14
-rw-r--r--libkdchart/KDChartPainter.cpp14
-rw-r--r--libkdchart/KDChartParams.cpp44
-rw-r--r--libkdchart/KDChartParams.h4
-rw-r--r--libkdchart/KDChartParams_io.cpp10
-rw-r--r--libkdchart/KDChartPiePainter.cpp2
-rw-r--r--libkdchart/KDChartPolarPainter.cpp2
-rw-r--r--libkdchart/KDChartPropertySet.h6
-rw-r--r--libkdchart/KDChartRingPainter.cpp2
-rw-r--r--libkdchart/KDChartWidget.cpp6
-rw-r--r--libkdchart/KDDrawText.cpp2
-rw-r--r--libkdchart/KDFrameProfileSection.h2
21 files changed, 79 insertions, 79 deletions
diff --git a/libkdchart/KDChart.cpp b/libkdchart/KDChart.cpp
index 5d0c6bf..4d8fd0c 100644
--- a/libkdchart/KDChart.cpp
+++ b/libkdchart/KDChart.cpp
@@ -302,7 +302,7 @@ void KDChart::paint( TQPainter* painter,
}
//qDebug("xxx" );
if( (params || data) && !setupGeometry( painter, params, data, drawRect ) ){
- qDebug("ERROR: KDChart::paint() could not calculate the chart tqgeometry.");
+ qDebug("ERROR: KDChart::paint() could not calculate the chart geometry.");
bOk = false;
}
}else{
@@ -439,12 +439,12 @@ TQString KDChart::globals()
}
globals += TQString::fromLatin1( "const KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT=\"%1\";\n" )
- .tqarg( TQString::fromLatin1( KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT ) );
+ .arg( TQString::fromLatin1( KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT ) );
globals += TQString::fromLatin1( "const KDCHART_AXIS_LABELS_AUTO_LIMIT = 140319.64;\n" );
globals += TQString::fromLatin1( "const KDCHART_DEFAULT_AXIS_GRID_COLOR = new Color(\"%1\");\n" )
- .tqarg(KDCHART_DEFAULT_AXIS_GRID_COLOR.name());
+ .arg(KDCHART_DEFAULT_AXIS_GRID_COLOR.name());
globals += TQString::fromLatin1( "const KDCHART_DATA_VALUE_AUTO_COLOR = new Color(\"%1\");\n" )
- .tqarg( (KDCHART_DATA_VALUE_AUTO_COLOR)->name());
+ .arg( (KDCHART_DATA_VALUE_AUTO_COLOR)->name());
TQMap<char*,TQColor> colorMap;
diff --git a/libkdchart/KDChartAreaPainter.cpp b/libkdchart/KDChartAreaPainter.cpp
index 6c47aee..2fca8d6 100644
--- a/libkdchart/KDChartAreaPainter.cpp
+++ b/libkdchart/KDChartAreaPainter.cpp
@@ -43,7 +43,7 @@
KDChartLinesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartAxesPainter.cpp b/libkdchart/KDChartAxesPainter.cpp
index 3f3b312..ee9dc87 100644
--- a/libkdchart/KDChartAxesPainter.cpp
+++ b/libkdchart/KDChartAxesPainter.cpp
@@ -65,7 +65,7 @@ int secondsSinceUTCStart( const TQDateTime& dt )
KDChartPainter( params )
{
// Intentionally left blank.
- // We cannot setup the tqgeometry yet
+ // We cannot setup the geometry yet
// since we do not know the size of the painter.
}
@@ -2823,7 +2823,7 @@ void KDChartAxesPainter::calculateLabelTexts(
const double secHour = 60.0 * secMin;
const double secDay = 24.0 * secHour;
//
- // we temporarily disable week tqalignment until bug
+ // we temporarily disable week alignment until bug
// is fixed (1st week of year must not start in the
// preceeding year but rather be shown incompletely)
//
@@ -3661,7 +3661,7 @@ TQString KDChartAxesPainter::truncateBehindComma( const double nVal,
sVal.setNum( nVal, 'f', bUseAutoDigits ? nTrustedPrecision
: TQMIN(behindComma, nTrustedPrecision) );
//qDebug("nVal: %f sVal: "+sVal, nVal );
- //qDebug( TQString(" %1").tqarg(sVal));
+ //qDebug( TQString(" %1").arg(sVal));
if ( bUseAutoDigits ) {
int comma = sVal.find( '.' );
if ( -1 < comma ) {
@@ -3697,7 +3697,7 @@ TQString KDChartAxesPainter::truncateBehindComma( const double nVal,
}
}
}
- //qDebug( TQString(" - %1").tqarg(trueBehindComma));
+ //qDebug( TQString(" - %1").arg(trueBehindComma));
return sVal;
}
diff --git a/libkdchart/KDChartBWPainter.cpp b/libkdchart/KDChartBWPainter.cpp
index 9f6e5fb..7fed752 100644
--- a/libkdchart/KDChartBWPainter.cpp
+++ b/libkdchart/KDChartBWPainter.cpp
@@ -55,7 +55,7 @@
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
@@ -291,7 +291,7 @@ void KDChartBWPainter::specificPaintData( TQPainter* painter,
const bool noBrush = TQt::NoBrush == params()->bWChartBrush().style();
- // Loop over the datasets, draw one box and whisker tqshape for each series.
+ // Loop over the datasets, draw one box and whisker shape for each series.
for ( uint dataset = chartDatasetStart;
dataset <= chartDatasetEnd;
++dataset ) {
diff --git a/libkdchart/KDChartBarPainter.cpp b/libkdchart/KDChartBarPainter.cpp
index f8ae89d..8bfe1a7 100644
--- a/libkdchart/KDChartBarPainter.cpp
+++ b/libkdchart/KDChartBarPainter.cpp
@@ -48,7 +48,7 @@ KDChartBarPainter::KDChartBarPainter( KDChartParams* params ) :
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
@@ -226,7 +226,7 @@ void KDChartBarPainter::specificPaintData( TQPainter* painter,
? 0.0
: static_cast<int>( valueBlockGap ) * numValues;
- // Set some tqgeometry values that apply to bar charts only
+ // Set some geometry values that apply to bar charts only
double totalNumberOfBars = 0.0;
double spaceBetweenDatasets = 0.0;
switch ( params()->barChartSubType() ) {
diff --git a/libkdchart/KDChartCustomBox.h b/libkdchart/KDChartCustomBox.h
index 223920e..823dd2c 100644
--- a/libkdchart/KDChartCustomBox.h
+++ b/libkdchart/KDChartCustomBox.h
@@ -181,7 +181,7 @@ public:
\param deltaAlign The way how \c deltaX and \deltaY affect the position of the box.
Leave this parameter to its default value KDCHART_AlignAuto to have the delta values
used according to the box's main \c align settings, otherwise specify your own
- tqalignment settings: e.g. right means there will be a gap between the right side of
+ alignment settings: e.g. right means there will be a gap between the right side of
the box and its anchor point - if the main \c align parameter is set to right too
the anchor point will to be outside of the box / if \c align is set to left
(but the \c deltaAlign to right) the anchor point will be inside the box.
@@ -192,7 +192,7 @@ public:
\li \c TQt::AlignRight | TQt::AlignTop
\li \c TQt::AlignRight | TQt::AlignBottom
Using AlignVCenter or AlignHCenter or AlignCenter does not make sense here:
- center delta tqalignment will cause KDChart to ignore the respective delta
+ center delta alignment will cause KDChart to ignore the respective delta
settings: deltaX or deltaY or both will become ineffective.
\param deltaScaleGlobal If true the actual delta X and delta Y values will
be calculated by \c deltaX and \c deltaY based upon the size of the
@@ -297,7 +297,7 @@ public:
\param deltaAlign The way how \c deltaX and \deltaY affect the position of the box.
Leave this parameter to its default value KDCHART_AlignAuto to have the delta values
used according to the box's main \c align settings, otherwise specify your own
- tqalignment settings: e.g. TQt::AlignRight means the box will be moved to the left
+ alignment settings: e.g. TQt::AlignRight means the box will be moved to the left
(by the amount calculated using the \c deltaX value), so there will be a gap
between the right side of the box and its anchor point IF the main \c align flag
is set to TQt::AlignRight too, so the anchor point will to be outside of the
@@ -310,7 +310,7 @@ public:
\li \c TQt::AlignRight | TQt::AlignTop
\li \c TQt::AlignRight | TQt::AlignBottom
Using AlignVCenter or AlignHCenter or AlignCenter does not make sense here:
- center delta tqalignment will cause KDChart to ignore the respective delta
+ center delta alignment will cause KDChart to ignore the respective delta
settings: deltaX or deltaY or both will become ineffective.
\note Moving of the box due to \c deltaAlign settings is applied after
the box is rotated: e.g. this means a gap specified by \c deltaAlign = TQt::AlignTop
@@ -643,7 +643,7 @@ public slots: // PENDING(blackie) merge slots sections.
Set this to KDHART_KDCHART_AlignAuto to have the delta values
used according to the box's main \c align settings, otherwise specify your own
- tqalignment settings: e.g. right means there will be a gap between the right side of
+ alignment settings: e.g. right means there will be a gap between the right side of
the box and its anchor point - if the main \c align parameter is set to right too
the anchor point will to be outside of the box / if \c align is set to left
(but the \c deltaAlign to right) the anchor point will be inside the box.
@@ -654,7 +654,7 @@ public slots: // PENDING(blackie) merge slots sections.
\li \c TQt::AlignRight | TQt::AlignTop
\li \c TQt::AlignRight | TQt::AlignBottom
Using AlignVCenter or AlignHCenter or AlignCenter does not make sense here:
- center delta tqalignment will cause KDChart to ignore the respective delta
+ center delta alignment will cause KDChart to ignore the respective delta
settings: deltaX or deltaY or both will become ineffective.
\note Moving of the box due to \c deltaAlign settings is applied after
the box is rotated: e.g. this means a gap specified by \c deltaAlign = TQt::AlignTop
diff --git a/libkdchart/KDChartEnums.h b/libkdchart/KDChartEnums.h
index 82956e8..b3fe163 100644
--- a/libkdchart/KDChartEnums.h
+++ b/libkdchart/KDChartEnums.h
@@ -240,7 +240,7 @@ public:
\image html "../refman_images/positions.png"
\image latex "../refman_images/positions.png" "the PositionFlag enum" width=4in
- \note The position and tqalignment of content to be printed at (or
+ \note The position and alignment of content to be printed at (or
inside of, resp.) an area or a point -- like for printing data value texts next
to their graphical representations (which might be a bar, line, pie slice,...) --
is specified by two parameters: a \c PositionFlag and a uint holding a combination of \c TQt::AlignmentFlags.
@@ -249,10 +249,10 @@ public:
The position of content and the way it is aligned to this
position is shown in the following drawing, note that annotation #2 and annotation #3
- share the same PositionFlag but have different tqalignment flags set:
+ share the same PositionFlag but have different alignment flags set:
- \image html "../refman_images/tqalignment.png"
- \image latex "../refman_images/tqalignment.png" "positioning and aligning" width=4in
+ \image html "../refman_images/alignment.png"
+ \image latex "../refman_images/alignment.png" "positioning and aligning" width=4in
\sa KDChartParams::setPrintDataValues
*/
diff --git a/libkdchart/KDChartHiLoPainter.cpp b/libkdchart/KDChartHiLoPainter.cpp
index bb8b2e3..d8f766c 100644
--- a/libkdchart/KDChartHiLoPainter.cpp
+++ b/libkdchart/KDChartHiLoPainter.cpp
@@ -49,7 +49,7 @@
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartLinesPainter.cpp b/libkdchart/KDChartLinesPainter.cpp
index a7e0109..9f0995e 100644
--- a/libkdchart/KDChartLinesPainter.cpp
+++ b/libkdchart/KDChartLinesPainter.cpp
@@ -56,7 +56,7 @@ KDChartLinesPainter::KDChartLinesPainter( KDChartParams* params ) :
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartObjectFactory.cpp b/libkdchart/KDChartObjectFactory.cpp
index 6e2a128..a53f84c 100644
--- a/libkdchart/KDChartObjectFactory.cpp
+++ b/libkdchart/KDChartObjectFactory.cpp
@@ -438,11 +438,11 @@ bool KDChartObjectFactory::isNumber( const TQVariant& v )
bool KDChartObjectFactory::checkArgCount( const TQString& className, int count, int min, int max )
{
if ( count < min ) {
- throwError( TQObject::tr( "Too few arguments when creating %1 object." ).tqarg( className ) );
+ throwError( TQObject::tr( "Too few arguments when creating %1 object." ).arg( className ) );
return false;
}
if ( count > max ) {
- throwError( TQObject::tr( "Too many arguments when creating %1 object." ).tqarg( className ) );
+ throwError( TQObject::tr( "Too many arguments when creating %1 object." ).arg( className ) );
return false;
}
return true;
@@ -453,7 +453,7 @@ bool KDChartObjectFactory::checkArgsIsTQtClass( const TQSArgumentList& args, int
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::TQObjectPtr || !arg.qobject()->inherits( expected ) ) {
- throwError( TQObject::tr( "Invalid type for argument no %1 to %2, must be a %3" ).tqarg(index).tqarg(constructing).tqarg(expected) );
+ throwError( TQObject::tr( "Invalid type for argument no %1 to %2, must be a %3" ).arg(index).arg(constructing).arg(expected) );
return false;
}
return true;
@@ -464,7 +464,7 @@ bool KDChartObjectFactory::getString( const TQSArgumentList& args, int index, TQ
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || arg.variant().type() != TQVariant::String ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a string" ).tqarg(index).tqarg(constructing) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a string" ).arg(index).arg(constructing) );
return false;
}
else {
@@ -477,7 +477,7 @@ bool KDChartObjectFactory::getNumber( const TQSArgumentList& args, int index, do
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || !isNumber(arg.variant()) ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a number" ).tqarg(index).tqarg( constructing ) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a number" ).arg(index).arg( constructing ) );
return false;
}
else {
@@ -508,7 +508,7 @@ bool KDChartObjectFactory::getBool( const TQSArgumentList& args, int index, bool
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || arg.variant().type() != TQVariant::Bool ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a boolean" ).tqarg(index).tqarg( constructing ) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a boolean" ).arg(index).arg( constructing ) );
return false;
}
else {
@@ -521,7 +521,7 @@ bool KDChartObjectFactory::checkIsTQtVariant( const TQSArgumentList& args, int i
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || arg.variant().type() != expected ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a %3").tqarg(index).tqarg(constructing).tqarg(variantName) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a %3").arg(index).arg(constructing).arg(variantName) );
return false;
}
else
diff --git a/libkdchart/KDChartParams.h b/libkdchart/KDChartParams.h
index 1672269..840ad12 100644
--- a/libkdchart/KDChartParams.h
+++ b/libkdchart/KDChartParams.h
@@ -393,7 +393,7 @@ public slots:
bool addFrameHeightToLayout = true )
{
_areaDict.setAutoDelete( TRUE );
- _areaDict.replace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
+ _areaDict.replace( TQString( "%1/-----/-----/-----" ).arg( area, 5 ),
new KDChartFrameSettings(0,0,0,
frame,
outerGapX,
@@ -436,7 +436,7 @@ public slots:
shadowWidth,
sunPos );
- _areaDict.replace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
+ _areaDict.replace( TQString( "%1/-----/-----/-----" ).arg( area, 5 ),
new KDChartFrameSettings( 0,0,0, frame,
outerGapX,
outerGapY,
diff --git a/libkdchart/KDChartParams_io.cpp b/libkdchart/KDChartParams_io.cpp
index 4f17e65..86f37d6 100644
--- a/libkdchart/KDChartParams_io.cpp
+++ b/libkdchart/KDChartParams_io.cpp
@@ -2194,12 +2194,12 @@ bool KDChartParams::loadXML( const TQDomDocument& doc )
TQString str;
if(areaId == KDChartEnums::AreaChartDataRegion)
str = TQString( "%1/%2/%3/%4" )
- .tqarg( areaId, 5 )
- .tqarg( frameSettings->dataRow(), 5 )
- .tqarg( frameSettings->dataCol(), 5 )
- .tqarg( 0, 5 );//frameSettings->data3rd(), 5 );
+ .arg( areaId, 5 )
+ .arg( frameSettings->dataRow(), 5 )
+ .arg( frameSettings->dataCol(), 5 )
+ .arg( 0, 5 );//frameSettings->data3rd(), 5 );
else
- str = TQString( "%1/-----/-----/-----" ).tqarg( areaId, 5 );
+ str = TQString( "%1/-----/-----/-----" ).arg( areaId, 5 );
_areaDict.replace( str, frameSettings );
}
}
diff --git a/libkdchart/KDChartPiePainter.cpp b/libkdchart/KDChartPiePainter.cpp
index 44f4c60..a8e126c 100644
--- a/libkdchart/KDChartPiePainter.cpp
+++ b/libkdchart/KDChartPiePainter.cpp
@@ -55,7 +55,7 @@
KDChartPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartPolarPainter.cpp b/libkdchart/KDChartPolarPainter.cpp
index 9ebed86..99cee95 100644
--- a/libkdchart/KDChartPolarPainter.cpp
+++ b/libkdchart/KDChartPolarPainter.cpp
@@ -50,7 +50,7 @@ KDChartPolarPainter::KDChartPolarPainter( KDChartParams* params ) :
KDChartPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartPropertySet.h b/libkdchart/KDChartPropertySet.h
index cdd64f7..d963af5 100644
--- a/libkdchart/KDChartPropertySet.h
+++ b/libkdchart/KDChartPropertySet.h
@@ -721,14 +721,14 @@ public slots:
}
/**
- Specify the ID of the property set specifying the tqalignment of the
+ Specify the ID of the property set specifying the alignment of the
Marker to be displayed for this data value
<b>or</b> specifying this flag directly.
\note This function should be used for Line Charts only, otherwise
the settings specified here will be ignored.
- \param idMarkerAlign ID of the property set specifying the tqalignment
+ \param idMarkerAlign ID of the property set specifying the alignment
of the Marker to be shown.
Use special value KDChartPropertySet::UndefinedID
to specify neither another property set's ID
@@ -737,7 +737,7 @@ public slots:
if you do NOT want to inherit another property set's
settings but want to specify the flag by using
the following parameter.
- \param markerAlign The tqalignment of the marker to be shown.
+ \param markerAlign The alignment of the marker to be shown.
This parameter is stored but ignored if the previous parameter
is not set to KDChartPropertySet::OwnID.
diff --git a/libkdchart/KDChartRingPainter.cpp b/libkdchart/KDChartRingPainter.cpp
index 8797da5..ba1e6fe 100644
--- a/libkdchart/KDChartRingPainter.cpp
+++ b/libkdchart/KDChartRingPainter.cpp
@@ -53,7 +53,7 @@
KDChartPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartWidget.cpp b/libkdchart/KDChartWidget.cpp
index d530ea1..8217abf 100644
--- a/libkdchart/KDChartWidget.cpp
+++ b/libkdchart/KDChartWidget.cpp
@@ -244,8 +244,8 @@ void KDChartWidget::resizeEvent( TQResizeEvent* /*event*/ )
display process, so this is turned off by default.
If active data reporting is turned on when the widget is already
- shown, data will be reported after the next tqrepaint(). Call
- tqrepaint() explicitly if necessary.
+ shown, data will be reported after the next repaint(). Call
+ repaint() explicitly if necessary.
Active data is currently supported for bar, pie, and line charts
(the latter only with markers, as trying to hit the line would be
@@ -281,7 +281,7 @@ bool KDChartWidget::isActiveData() const
needs to be kept around. However, in most cases, it is worth
spending the extra memory. Double-buffering is on by
default. Turning double-buffering on or off does not trigger a
- tqrepaint.
+ repaint.
\param doublebuffered if true, turns double-buffering on, if false,
turns double-buffering off
diff --git a/libkdchart/KDDrawText.cpp b/libkdchart/KDDrawText.cpp
index 70283da..c098513 100644
--- a/libkdchart/KDDrawText.cpp
+++ b/libkdchart/KDDrawText.cpp
@@ -408,7 +408,7 @@ void KDDrawText::drawRotatedTxt( TQPainter* painter,
painter->drawLine( x+pBotRight.x(), y+pBotRight.y()-3, x+pBotRight.x(), y+pBotRight.y()+3 );
*/
- // The horizontal and vertical tqalignment together define one of
+ // The horizontal and vertical alignment together define one of
// NINE possible points: this point must be moved on the anchor.
int hAlign = align & ( TQt::AlignLeft | TQt::AlignRight | TQt::AlignHCenter );
int vAlign = align & ( TQt::AlignTop | TQt::AlignBottom | TQt::AlignVCenter );
diff --git a/libkdchart/KDFrameProfileSection.h b/libkdchart/KDFrameProfileSection.h
index 9fe38ad..48f70bb 100644
--- a/libkdchart/KDFrameProfileSection.h
+++ b/libkdchart/KDFrameProfileSection.h
@@ -104,7 +104,7 @@ public:
/**
- Profile Curvature Mode: specifying the tqshape of a frame profile section.
+ Profile Curvature Mode: specifying the shape of a frame profile section.
(curvature setting will be ignored for \c DirPlain profiles)
\li \c CvtFlat looking like a evenly sloping surface.
diff --git a/libkdchart/KDChartPainter.cpp b/libkdchart/KDChartPainter.cpp
index df60857..5ec6109 100644
--- a/libkdchart/KDChartPainter.cpp
+++ b/libkdchart/KDChartPainter.cpp
@@ -103,7 +103,7 @@ _legendTitleWidth( 0 ),
_legendTitleMetricsHeight( 0 )
{
// This constructor intentionally left blank so far; we cannot setup the
// tqgeometry yet since we do not know the size of the painter.
}
/**
@@ -979,7 +979,7 @@ TQPoint KDChartPainter::calculateAnchor( const KDChartCustomBox & box,
// Rule:
//
// A box may be aligned to another box (and the 2nd box may again be
- // aligned to a 3rd box and so on) but NO CIRCULAR tqalignment is allowed.
+ // aligned to a 3rd box and so on) but NO CIRCULAR alignment is allowed.
//
if( !box.anchorBeingCalculated() ) {
@@ -1650,7 +1650,7 @@ void KDChartPainter::paintHeaderFooter( TQPainter* painter,
params()->headerFooterFontRelSize( iHdFt ) * averageValueP1000 ) );
painter->setPen( params()->headerFooterColor( iHdFt ) );
painter->setFont( actFont );
- // Note: The tqalignment flags used here match the rect calculation
+ // Note: The alignment flags used here match the rect calculation
// done in KDChartPainter::setupGeometry().
// AlignTop is done to ensure that the hd/ft texts of the same
// group (e.g. Hd2L and Hd2 and Hd2R) have the same baselines.
@@ -2063,7 +2063,7 @@ void KDChartPainter::calculateAllAxesRects(
int nAxesBottom = TQMAX( nAxesBottom0 + nAxesBottomADD, nMinDistance );
- // for micro tqalignment with the X axis, we adjust the Y axis - but not for Area Charts:
+ // for micro alignment with the X axis, we adjust the Y axis - but not for Area Charts:
// otherwise the areas drawn would overwrite the Y axis line.
int nAxesLeft = TQMAX( nAxesLeft0 + nAxesLeftADD, nMinDistance )
- (bIsAreaChart ? 0 : 1);
@@ -2143,10 +2143,10 @@ void KDChartPainter::calculateAllAxesRects(
/**
This method will be called whenever any parameters that affect
- tqgeometry have been changed. It will compute the appropriate
+ geometry have been changed. It will compute the appropriate
positions for the various parts of the chart (legend, axes, data
area etc.). The implementation in KDChartPainter computes a
- standard tqgeometry that should be suitable for most chart
+ standard geometry that should be suitable for most chart
types. Subclasses can provide their own implementations.
\param data the data that will be displayed as a chart
@@ -2158,7 +2158,7 @@ void KDChartPainter::setupGeometry( TQPainter* painter,
const TQRect& drawRect )
{
//qDebug("INVOKING: KDChartPainter::setupGeometry()");
- // avoid recursion from tqrepaint() being called due to params() changed signals...
+ // avoid recursion from repaint() being called due to params() changed signals...
const bool oldBlockSignalsState = params()->signalsBlocked();
const_cast < KDChartParams* > ( params() )->blockSignals( true );
@@ -103,7 +103,7 @@ _legendTitleWidth( 0 ),
{
// This constructor intentionally left blank so far; we cannot setup the
- // tqgeometry yet since we do not know the size of the painter.
+ // geometry yet since we do not know the size of the painter.
}
/**
diff --git a/libkdchart/KDChartParams.cpp b/libkdchart/KDChartParams.cpp
index aac8928..deedda9 100644
--- a/libkdchart/KDChartParams.cpp
+++ b/libkdchart/KDChartParams.cpp
@@ -707,7 +707,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
break;
++i;
}while( properties(id, propSet) );
// retrieve marker tqalignment
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnMarkerAlign( id, markerAlign ) ){
@@ -750,7 +750,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// extra lines:
// retrieve tqalignment of extra lines
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnExtraLinesAlign( id, extraLinesAlign ) ){
@@ -813,7 +813,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// markers at the ends of the extra lines:
// retrieve marker tqalignment
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnExtraMarkersAlign( id, extraMarkersAlign ) ){
@@ -976,7 +976,7 @@ aligned to.
This must be a reasonable combination of TQt::AlignmentFlags.
\param negativeDeltaX The X distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -987,7 +987,7 @@ size of the chart and the specification made via parameter \c size.
\param negativeDeltaY The Y distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1002,7 +1002,7 @@ special values that you might find usefull for Pie charts or for
Ring charts: \c KDCHART_SAGGITAL_ROTATION and \c
KDCHART_TANGENTIAL_ROTATION both leading to individual
calculation of appropriate rotation for each data value. Rotation
-will be performed around the internal <b>tqalignment point</b> of the
+will be performed around the internal <b>alignment point</b> of the
text -- specified by \c negativeAlign (or \c positiveAlign, resp.).
The following parameters apply to values greater than zero or equal zero:
@@ -1013,7 +1013,7 @@ aligned to.
This must be a reasonable combination of TQt::AlignmentFlags.
\param negativeDeltaX The X distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1023,7 +1023,7 @@ delta value are calculated dynamically before painting based on the
size of the chart and the specification made via parameter \c size.
\param positiveDeltaY The Y distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1038,7 +1038,7 @@ special values that you might find usefull for Pie charts or for
Ring charts: \c KDCHART_SAGGITAL_ROTATION and \c
KDCHART_TANGENTIAL_ROTATION both leading to individual
calculation of appropriate rotation for each data value. Rotation
-will be performed around the internal <b>tqalignment point</b> of the
+will be performed around the internal <b>alignment point</b> of the
text -- specified by \c negativeAlign (or \c positiveAlign, resp.).
\param layoutPolicy The way to handle too narrow space conflicts:
@@ -1872,10 +1872,10 @@ TQString KDChartParams::dataRegionFrameAreaName( uint dataRow,
uint data3rd )
{
return TQString( "%1/%2/%3/%4" )
- .tqarg( KDChartEnums::AreaChartDataRegion, 5 )
- .tqarg( dataRow, 5 )
- .tqarg( dataCol, 5 )
- .tqarg( data3rd, 5 );
+ .arg( KDChartEnums::AreaChartDataRegion, 5 )
+ .arg( dataRow, 5 )
+ .arg( dataCol, 5 )
+ .arg( data3rd, 5 );
}
@@ -2609,7 +2609,7 @@ const KDChartParams::KDChartFrameSettings* KDChartParams::frameSettings( uint ar
{
if( pIterIdx )
*pIterIdx = 0;
- const TQString key( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ) );
+ const TQString key( TQString( "%1/-----/-----/-----" ).arg( area, 5 ) );
KDChartFrameSettings* it = _areaDict.find( key );
bFound = ( it != 0 );
if( bFound )
@@ -2643,7 +2643,7 @@ const KDChartParams::KDChartFrameSettings* KDChartParams::frameSettings( uint ar
*/
bool KDChartParams::removeFrame( uint area )
{
- return _areaDict.remove( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ) );
+ return _areaDict.remove( TQString( "%1/-----/-----/-----" ).arg( area, 5 ) );
}
@@ -4617,7 +4617,7 @@ void KDChartParams::setThreeDBarAngle( uint angle )
point. Only used if chartType() == Line and if threeDLines() ==
false. The default is not to draw markers.
- \note Use the setLineMarkerStyle function to specify the tqshape
+ \note Use the setLineMarkerStyle function to specify the shape
of the markers, use the setLineWidth function to set the
width of the lines connecting the markers (or to surpress
drawing of such lines, resp.)
@@ -7487,7 +7487,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use those sections to show some marginal information
like department name, print date, page number... <br>
<b>Note:</b> Those headers <b>share the same area</b> so make sure to
- specify propper horizontal tqalignment for each section when using more than
+ specify propper horizontal alignment for each section when using more than
one of them. By default \c HdFtPosHeader0 has centered alignement,
\c HdFtPosHeader0L is aligned to the left and \c HdFtPosHeader0R to the
right side. All of them are vertically aligned to the bottom, you may
@@ -7504,7 +7504,7 @@ void KDChartParams::setAxisParams( uint n,
You could use this headers to show the main information such as project name,
chart title or period of time (e.g. census year). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
\li Up to three <b>additional headers</b> ( \c HdFtPosHeader2 , \c
@@ -7513,7 +7513,7 @@ void KDChartParams::setAxisParams( uint n,
This headers could show additional information such as project phase, chart
sub-title or sub-period of time (e.g. census quarter-year). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
<p>
@@ -7524,7 +7524,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use these footers instead of (or additional to) the
main header(s) for showing the main information... <br>
Like their header-counterparts they share the same part of the printable area
- so the restrictions regarding tqalignment mentioned above apply also to these
+ so the restrictions regarding alignment mentioned above apply also to these
three sections.
\li Up to three <b>additional footers</b> ( \c HdFtPosFooter2 , \c
@@ -7533,7 +7533,7 @@ void KDChartParams::setAxisParams( uint n,
This footers could show additional information instead of (or additional to)
the additional header(s). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
\li Up to three <b>trailing footers</b> ( \c HdFtPosFooter0 , \c
@@ -7542,7 +7542,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use those sections to show some marginal information
instead of (or additional to) the leading header(s). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
\note The names \c HdFtPosHeader or \c HdFtPosFooter are the basic names also returned by \c basicAxisPos.
@@ -707,7 +707,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
}while( properties(id, propSet) );
- // retrieve marker tqalignment
+ // retrieve marker alignment
propSet.deepCopy( &startSet ); i=0;
do{
@@ -750,7 +750,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// extra lines:
- // retrieve tqalignment of extra lines
+ // retrieve alignment of extra lines
propSet.deepCopy( &startSet ); i=0;
do{
@@ -813,7 +813,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// markers at the ends of the extra lines:
- // retrieve marker tqalignment
+ // retrieve marker alignment
propSet.deepCopy( &startSet ); i=0;
do{